@@ -6,10 +6,11 @@
 }
 
 get_status_message <- function() {
-  httr2::request("https://raw.githubusercontent.com/aleksanderbl29/dawaR/refs/heads/main/status-message") |>
+  body <- httr2::request("https://raw.githubusercontent.com/aleksanderbl29/dawaR/refs/heads/main/status-message") |>
     httr2::req_perform() |>
-    httr2::resp_body_string() |>
-    gsub("\\n", "\n", x = _)
+    httr2::resp_body_string()
+
+  gsub("\\n", "\n", x = body)
 }
 # nolint end
 
